@@ -15,11 +15,11 @@ import copy
 from distutils.version import LooseVersion
 import logging
 import os
+import re
 import time
 import uuid
 import subprocess
 import json
-import errno
 
 import kitchen.text.converters
 
@@ -399,6 +399,9 @@ class TaskWarriorDirect(TaskWarriorBase):
         self._task_remove(line, Status.to_file(original_status))
         return task
 
+# This regex is used to parse UUIDs from messages output
+# by the shell client when creating tasks.
+UUID_REGEX = '[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}'
 
 class TaskWarriorShellout(TaskWarriorBase):
     """ Interacts with taskwarrior by invoking shell commands.
@@ -417,6 +420,9 @@ class TaskWarriorShellout(TaskWarriorBase):
         'dependency': {
             'confirmation': 'no',
         },
+        'recurrence': {
+            'confirmation': 'no'
+        },
     }
 
     def __init__(
@@ -447,11 +453,12 @@ class TaskWarriorShellout(TaskWarriorBase):
         command = (
             [
                 'task',
-                'rc:%s' % self.config_filename,
             ]
             + self.get_configuration_override_args()
             + [six.text_type(arg) for arg in args]
         )
+        env = os.environ.copy()
+        env['TASKRC'] = self.config_filename
 
         # subprocess is expecting bytestrings only, so nuke unicode if present
         # and remove control characters
@@ -463,14 +470,15 @@ class TaskWarriorShellout(TaskWarriorBase):
         try:
             proc = subprocess.Popen(
                 command,
+                env=env,
                 stdout=subprocess.PIPE,
                 stderr=subprocess.PIPE,
             )
             stdout, stderr = proc.communicate()
-        except OSError as e:
-            if e.errno == errno.ENOENT:
-                raise OSError("Unable to find the 'task' command-line tool.")
-            raise
+        except FileNotFoundError:
+            raise FileNotFoundError(
+                "Unable to find the 'task' command-line tool."
+            )
 
         if proc.returncode != 0:
             raise TaskwarriorError(command, stderr, stdout, proc.returncode)
@@ -541,8 +549,8 @@ class TaskWarriorShellout(TaskWarriorBase):
         """
         try:
             return cls.get_version() > LooseVersion('2')
-        except OSError:
-            # OSError is raised if subprocess.Popen fails to find
+        except FileNotFoundError:
+            # FileNotFound is raised if subprocess.Popen fails to find
             # the executable.
             return False
 
@@ -553,10 +561,10 @@ class TaskWarriorShellout(TaskWarriorBase):
                 ['task', '--version'],
                 stdout=subprocess.PIPE
             ).communicate()[0]
-        except OSError as e:
-            if 'No such file or directory' in e:
-                raise OSError("Unable to find the 'task' command-line tool.")
-            raise
+        except FileNotFoundError:
+            raise FileNotFoundError(
+                "Unable to find the 'task' command-line tool."
+            )
         return LooseVersion(taskwarrior_version.decode())
 
     def sync(self, init=False):
@@ -686,7 +694,7 @@ class TaskWarriorShellout(TaskWarriorBase):
         # when adding a task.  Instead, you have to specify rc.verbose=new-uuid
         # and then parse the assigned uuid out from stdout.
         if self.get_version() >= LooseVersion('2.4'):
-            task['uuid'] = stdout.strip().split()[-1].strip('.')
+            task['uuid'] = re.search(UUID_REGEX, stdout).group(0)
 
         id, added_task = self.get_task(uuid=task['uuid'])
 
@@ -821,7 +829,7 @@ class TaskWarriorShellout(TaskWarriorBase):
         if task['status'] == Status.DELETED:
             raise ValueError("Task is already deleted.")
 
-        self._execute(id, 'delete')
+        self._execute(task['uuid'], 'delete')
         return self.get_task(uuid=task['uuid'])[1]
 
     def task_start(self, **kw):
